<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../src/core/ui/about.cpp" line="41"/>
        <source>About</source>
        <translation>O aplikácií</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="42"/>
        <source>Thanks</source>
        <translation>Poďakovanie</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="43"/>
        <source>Help us</source>
        <translation>Pomôžte s vývojom</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="100"/>
        <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
        <translation>je multiplatformová aplikácia pre rýchle fotografovanie pracovnej plochy.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="102"/>
        <source>It is a light and powerful application, written in Qt.</source>
        <translation>Je to jednoduchá a funkčná aplikácia naprogramovaná v Qt.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="34"/>
        <source>using Qt %1</source>
        <translation>pomocou Qt %1</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="105"/>
        <source>Website - &lt;a href=&quot;%1&quot;&gt;%1&lt;/a&gt;</source>
        <translation>Webové stránky – &lt;a href=&quot;%1&quot;&gt;%1&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="108"/>
        <source>Licensed under the &lt;a href=%1&gt;GPL v2&lt;/a&gt;</source>
        <translation>Pod licenciou &lt;a href=%1&gt;GPL v2&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="112"/>
        <source>Copyright &amp;copy; 2009-2013, Artem &apos;DOOMer&apos; Galichkin</source>
        <translation>Autorské právo &amp;copy; 2009-2013, Artem „DOOMer“ Galichkin</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="119"/>
        <source>You can join us and help us if you want. This is an invitation if you like this application.</source>
        <translation>Ak chcete, môžete sa pripojiť k nášmu tímu. Touto cestou vás pozývame ak sa vám aplikácia páči.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="122"/>
        <source>What you can do?</source>
        <translation>Ako môžete pomôcť?</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="125"/>
        <source>Translate ScreenGrab to other languages</source>
        <translation>Prekladať ScreenGrab do ďalších jazykov</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="126"/>
        <source>Make suggestions for next releases</source>
        <translation>Robiť návrhy do ďalších verzií</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="127"/>
        <source>Report bugs and issues</source>
        <translation>Nahlasovať chyby a problémy</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="130"/>
        <source>Bug tracker</source>
        <translation>Bug tracker</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="140"/>
        <source>Translate:</source>
        <translation>Preklady:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="142"/>
        <source> Brazilian Portuguese translation</source>
        <translation> Brazílska portugalčina</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="143"/>
        <source>Marcio Moraes</source>
        <translation>Marcio Moraes</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="145"/>
        <source> Ukrainian translation</source>
        <translation> Ukrajinčina</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="146"/>
        <source>Gennadi Motsyo</source>
        <translation>Gennadi Motsyo</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="148"/>
        <source> Spanish translation</source>
        <translation> Španielčina</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="149"/>
        <source>Burjans L García D</source>
        <translation>Burjans L García D</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="151"/>
        <source> Italian translation</source>
        <translation> Taliančina</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="155"/>
        <source>Testing:</source>
        <translation>Testovanie:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="157"/>
        <source>Dual monitor support and other in Linux</source>
        <translation>Podpora dvoch monitorov a ďalšie v Linuxe</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="158"/>
        <source>Dual monitor support in Linux</source>
        <translation>Podpora dvoch monitorov v Linuxe</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="159"/>
        <source>win32-build [Windows XP and 7]</source>
        <translation>win32-build [Windows XP a 7]</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="160"/>
        <source>old win32-build [Windows Vista]</source>
        <translation>starší win32-build [Windows Vista]</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="161"/>
        <source>win32-build [Windows 7]</source>
        <translation>win32-build [Windows 7]</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="182"/>
        <source>Directory %1 does not exist. Do you want to create it?</source>
        <translation>Priečinok %1 neexistuje. Prajete si ho vytvoriť?</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="183"/>
        <location filename="../src/core/ui/configwidget.cpp" line="271"/>
        <source>Warning</source>
        <translation>Upozornenie</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="259"/>
        <source>Select directory</source>
        <translation>Vybrať priečinok</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="270"/>
        <source>Do you want to reset the settings to the defaults?</source>
        <translation>Prajete si vrátiť nastavenia do pôvodných hodnôt?</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="314"/>
        <source>Example: </source>
        <translation>Príklad: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="355"/>
        <source>This key is already used in ScreenGrab! Please select another.</source>
        <translation>ScreenGrab už túto klávesu používa. Vyberte inú.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="373"/>
        <source>This key is not supported on your system!</source>
        <translation>Túto klávesu váš operačný systém nepodporuje!</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="393"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
</context>
<context>
    <name>Core</name>
    <message>
        <location filename="../src/core/core.cpp" line="64"/>
        <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
        <translation>je multiplatformová aplikácia pre rýchle fotografovanie pracovnej plochy.</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="68"/>
        <source>Take a fullscreen screenshot</source>
        <translation>Odfotiť celú obrazovku</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="72"/>
        <source>Take a screenshot of the active window</source>
        <translation>Odfotiť aktívne okno</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="76"/>
        <source>Take a screenshot of a selection of the screen</source>
        <translation>Odfotiť vybranú časť obrazovku</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="80"/>
        <source>Run the application with a hidden main window</source>
        <translation>Spustiť aplikáciu a skryť jej hlavné okno</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="450"/>
        <source>Saved</source>
        <translation>Uložené</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="450"/>
        <source>Saved to </source>
        <translation>Uložené do </translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="472"/>
        <source>Name of saved file is copied to the clipboard</source>
        <translation>Názov uloženého súboru je skopírovaný v schránke</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="478"/>
        <source>Path to saved file is copied to the clipboard</source>
        <translation>Cesta k uloženému súboru je uložená v schránke</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="501"/>
        <source>Copied</source>
        <translation>Skopírované</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="501"/>
        <source>Screenshot is copied to clipboard</source>
        <translation>Snímka obrazovky je skopírovaná v schránke</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="14"/>
        <source>ScreenGrab</source>
        <translation>ScreenGrab</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="79"/>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="89"/>
        <source>Type of screenshot</source>
        <translation>Typ snímky obrazovky</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="96"/>
        <source>Full screen</source>
        <translation>Celá obrazovka</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="101"/>
        <source>Window</source>
        <translation>Okno</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="106"/>
        <source>Screen area</source>
        <translation>Časť obrazovky</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="111"/>
        <source>Last selected area</source>
        <translation>Naposledy vybratá oblasť</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="141"/>
        <source>Delay:</source>
        <translation>Počkať:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="154"/>
        <source>Delay in seconds before taking screenshot</source>
        <translation>Program zadaný čas (v sekundách) počká, potom odfotí obrazovku</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="157"/>
        <source>None</source>
        <translation>Nie</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="160"/>
        <source> sec</source>
        <translation> sek</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="203"/>
        <source>Zoom area around mouse</source>
        <translation>Priblížiť oblasť okolo myši</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="210"/>
        <source>No window decoration</source>
        <translation>Bez dekorácie okna</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="217"/>
        <source>Include mouse pointer</source>
        <translation>Odfotiť aj kurzor myši</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="246"/>
        <source>toolBar</source>
        <translation>nástroje</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="45"/>
        <source>New</source>
        <translation>Nový</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="46"/>
        <source>Save</source>
        <translation>Uložiť</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="47"/>
        <source>Copy</source>
        <translation>Kopírovať</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="48"/>
        <source>Options</source>
        <translation>Nastavenia</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="49"/>
        <location filename="../src/core/ui/mainwindow.cpp" line="73"/>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="50"/>
        <source>About</source>
        <translation>O programe</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="51"/>
        <source>Quit</source>
        <translation>Ukončiť</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="315"/>
        <source>Screenshot </source>
        <translation>Snímka obrazovky </translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="319"/>
        <source>Double click to open screenshot in external default image viewer</source>
        <translation>Dvojklikom otvoríte snímku v predvolenom prehliadači obrázkov</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="328"/>
        <location filename="../src/core/ui/mainwindow.cpp" line="459"/>
        <source>Hide</source>
        <translation>Skryť</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="466"/>
        <source>Show</source>
        <translation>Zobraziť</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="519"/>
        <source>%1 Files</source>
        <translation>%1 súborov</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="541"/>
        <source>Save As...</source>
        <translation>Uložiť ako...</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/core/regionselect.cpp" line="175"/>
        <source>Click and drag to draw a rectangle,
right click to fit to edges,
double click or press Enter
to take a screenshot.</source>
        <translation>Kliknutím a nakreslíte obdĺžnik,
pravé tlačidlo myši prispôsobí
obdĺžnik hranám,
dvojklik alebo Enter vytvorí
snímku obrazovky.</translation>
    </message>
    <message>
        <location filename="../src/core/regionselect.cpp" line="207"/>
        <source>%1 x %2 pixels </source>
        <translation>%1 x %2 pixelov </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/modules/extedit/moduleextedit.cpp" line="35"/>
        <source>External edit</source>
        <translation>Upraviť v aplikácií</translation>
    </message>
    <message>
        <location filename="../src/modules/extedit/moduleextedit.cpp" line="46"/>
        <source>Edit in...</source>
        <translation>Upraviť pomocou...</translation>
    </message>
</context>
<context>
    <name>aboutWidget</name>
    <message>
        <location filename="../src/core/ui/aboutwidget.ui" line="118"/>
        <source>About Qt</source>
        <translation>O Qt</translation>
    </message>
    <message>
        <location filename="../src/core/ui/aboutwidget.ui" line="144"/>
        <source>Close</source>
        <translation>Zavrieť</translation>
    </message>
</context>
<context>
    <name>configwidget</name>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="26"/>
        <location filename="../src/core/ui/configwidget.ui" line="568"/>
        <source>Options</source>
        <translation>Nastavenia</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="77"/>
        <source>Main</source>
        <translation>Hlavné</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="82"/>
        <source>Advanced</source>
        <translation>Pokročilé</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="87"/>
        <source>System tray</source>
        <translation>Systémový panel</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="92"/>
        <source>Shortcuts</source>
        <translation>Skratky</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="116"/>
        <source>Default save directory</source>
        <translation>Predvolený priečinok</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="122"/>
        <source>Path to default selection dir for saving</source>
        <translation>Cesta k predvolenému priečinku; do tohoto priečinka sa budú ukladať snímky</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="135"/>
        <source>Browse filesystem</source>
        <translation>Vybrať priečinok v počítači</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="138"/>
        <source>Browse</source>
        <translation>Vybrať</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="148"/>
        <source>Default file</source>
        <translation>Predvolený súbor</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="161"/>
        <source>Name:</source>
        <translation>Názov:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="168"/>
        <source>Default filename</source>
        <translation>Predvolený názov súboru</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="179"/>
        <source>Format</source>
        <translation>Formát</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="192"/>
        <source>Default saving image format</source>
        <translation>Predvolený formát ukladaných obrázkov</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="211"/>
        <source>Copy file name to the clipboard when saving</source>
        <translation>Kopírovať názov uloženého súboru do schránky</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="225"/>
        <source>Do not copy</source>
        <translation>Nekopírovať</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="230"/>
        <source>Copy file name only</source>
        <translation>Skopírovať názov súboru</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="235"/>
        <source>Copy full file path</source>
        <translation>Skopírovať celú cestu k súboru</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="245"/>
        <source>Image quality</source>
        <translation>Kvalita obrázka</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="251"/>
        <source>Image quality (1 - small file, 100 - high quality)</source>
        <translation>Kvalita obrázka (1 – malý súbor, 100 – vysoká kvalita)</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="316"/>
        <source>Inserting current date time into saved filename</source>
        <translation>Do názvu uloženého súboru sa pridá aktuálny čas a dátum</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="319"/>
        <source>Insert current date and time in file name</source>
        <translation>Pridať do názvu súboru čas a dátum</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="328"/>
        <source>Template: </source>
        <translation>Formát času: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="353"/>
        <source>Example: </source>
        <translation>Príklad: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="363"/>
        <source>Automatically saving screenshots in grabbing process</source>
        <translation>Po odfotení obrazovky automaticky uložiť snímku</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="366"/>
        <source>Autosave screenshot</source>
        <translation>Automaticky uložiť snímku</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="378"/>
        <source>Save first screenshot</source>
        <translation>Uložiť prvú snímku</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="387"/>
        <source>Allow run multiplies copy of ScreenGrab</source>
        <translation>Umožniť spustenie viacerých inštancií programu</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="390"/>
        <source>Allow multiple instances of ScreenGrab</source>
        <translation>Povoliť viacero inštancií programu</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="397"/>
        <source>Open in external viewer on double click</source>
        <translation>Dvojklikom snímku otvoríte v externom prehliadači</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="400"/>
        <source>Enable external viewer</source>
        <translation>Použiť externý prehliadač</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="407"/>
        <source>If this is unchecked, the selected area
might become larger to fit to outer edges</source>
        <translation>Ak políčko nie je zaškrtnuté, váš výber
sa môže zväčšiť, aby sa do neho zmestili vonkajšie hrany</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="411"/>
        <source>Fit to edges inside selected area by right clicking</source>
        <translation>Pri kreslení výberu pravým tlačidlom myši automaticky prispôsobiť hranám</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="418"/>
        <source>Notify on saving and copying</source>
        <translation>Upozorniť na uloženie a kopírovanie</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="427"/>
        <source>Duration:</source>
        <translation>Trvanie:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="494"/>
        <source>Show ScreenGrab in the system tray</source>
        <translation>Zobraziť ScreenGrab na systémovom paneli</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="434"/>
        <source> sec</source>
        <translation> sek</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="501"/>
        <source>Minimize to tray on click close button</source>
        <translation>Pri zavretí minimalizovať na systémový panel</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="504"/>
        <source>Minimize to tray when closing</source>
        <translation>Pri zavretí minimalizovať na systémový panel</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="543"/>
        <source>Action</source>
        <translation>Akcia</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="548"/>
        <source>Shortcut</source>
        <translation>Skratka</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="553"/>
        <source>New screen</source>
        <translation>Nová obrazovka</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="558"/>
        <source>Save screen</source>
        <translation>Uložiť obrazovku</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="563"/>
        <source>Copy screen</source>
        <translation>Kopírovať obrazovku</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="573"/>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="578"/>
        <source>Quit</source>
        <translation>Ukončiť</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="588"/>
        <source>Selected shortcut:</source>
        <translation>Klávesová skratka:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="595"/>
        <source>Not defined</source>
        <translation>Neurčená</translation>
    </message>
</context>
</TS>
